require "rails_helper"

#-#-#-#-#REST#-#-#-#-#
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Index" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # get /api/1/users
    it "Gets all of the users" do
      FactoryGirl.create_list(:fbuser_user_1, 10)
      get 'api/1/users', nil, @header
      expect(response.status).to eq(200) #ok
      expect(::Fbuser::V1::User.count).to eq(11)
      expect(json["users"].length).to eq(11)
    end
  end
end
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Show" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # get /api/1/users/1
    it "Gets a user by id" do
      user = FactoryGirl.create(:fbuser_user_1)
      get "api/1/users/#{user.id}", nil, @header
      expect(response.status).to eq(200) #ok
    end
  end
end
=begin
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Create" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # post /api/1/users
    it "Creates user" do
      attrs = FactoryGirl.attributes_for(:fbuser_user_1)
      #attrs[:column] = "LaunchU"  
      hash = {"user" => attrs}
      post 'api/1/users', hash, @header
      expect(response.status).to eq(200) #ok
    end
  end
end
=end
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Update" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # patch/put /api/1/users/1
    it "Updates user" do
      #Create the user through the api
      attrs = FactoryGirl.attributes_for(:fbuser_user_1)
      #attrs[:column] = "LaunchU"  
      user = FactoryGirl.create(:fbuser_user_1)
      hash = {"user" => attrs}
      put "api/1/users/#{user.id}", hash, @header
      expect(response.status).to eq(200) #ok
    end
  end
end
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Destroy" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # delete /api/1/users/1
    it "Deletes user" do
      #Create the user through the api
      attrs = FactoryGirl.attributes_for(:fbuser_user_1)
      #attrs[:column] = "LaunchU"  
      user = FactoryGirl.create(:fbuser_user_1)
      expect(Fbuser::V1::User.count).to eq(2)
      #Now delete the user through the api
      delete "api/1/users/#{user.id}", nil, @header
      expect(json).to eq({})
      expect(response.status).to eq(200) #ok
      expect(Fbuser::V1::User.count).to eq(1)
    end
  end
end
#-#-#-#-#Collection Routes#-#-#-#-#
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Collection Routes" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # get /api/1/collection
    it "checks response of a collection route" do

    end
  end
end
#-#-#-#-#Serialization#-#-#-#-#
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Serialization" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    it "checks the index json sent back" do

    end
  end
end
#-#-#-#-#Errors#-#-#-#-#
RSpec.describe ::Fbuser::V1::User, :type => :request do
  describe "Errors" do
    before(:example) do
      @user = FactoryGirl.create(:fbuser_user_1)
      token = @user.tokens[0].auth_token
      @header = {::Settings.token_header => token, ::Settings.main_api_header => ::Settings.main_api_key}
    end
    # get /api/1/users/1
    it "checks for a 404" do
      user = FactoryGirl.create(:fbuser_user_1)
      get "api/1/users/#{user.id + 1}", nil, @header
      expect(response.status).to eq(404) #ok
    end
  end
end